==> haskell-streaming-commons-0.2.3.0-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 streaming-commons
version:              0.2.3.0
visibility:           public
id:                   streaming-commons-0.2.3.0-D3XRiPWqVFx7sJWamKd7Ei
key:                  streaming-commons-0.2.3.0-D3XRiPWqVFx7sJWamKd7Ei
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  f1a33244f8eb94aff62b03507bba1139
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-streaming-commons
hs-libraries:         HSstreaming-commons-0.2.3.0-D3XRiPWqVFx7sJWamKd7Ei
depends:
    array-0.5.4.0 async-2.2.5-Cu6iyHAzE8GPfJTsQBFL9 base-4.17.2.1
    bytestring-0.11.5.3 directory-1.3.7.1
    network-3.1.4.0-Ds1jGwhI6OBB7cQ3449UkE process-1.6.18.0
    random-1.2.1.3-6y99CLYUqOs4N5Dmmd11Ha stm-2.5.1.0 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3 zlib-0.7.0.0-30oOQFSD0dHCSPuXH9d3q6

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-streaming-commons-0.2.3.0-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 streaming-commons
version:              0.2.3.0
visibility:           public
id:                   streaming-commons-0.2.3.0-G1dRBX9majTL5ZeBqA3Cza
key:                  streaming-commons-0.2.3.0-G1dRBX9majTL5ZeBqA3Cza
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  7fe1d65d47a09ce23868167e08295549
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-streaming-commons
hs-libraries:         HSstreaming-commons-0.2.3.0-G1dRBX9majTL5ZeBqA3Cza
depends:
    array-0.5.4.0 async-2.2.5-9OoNXaJHjfh1odoyocMP2h base-4.17.2.1
    bytestring-0.11.5.3 directory-1.3.7.1
    network-3.1.4.0-Lt9YSaQDSdWKRzslp3ePNQ process-1.6.18.0
    random-1.2.1.3-BGGJ1HKj6xm3DkCP4JY8iZ stm-2.5.1.0 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3 zlib-0.7.0.0-4FpdxOqQBdK9wzg7bW7HW9

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
